## tftp

This container does start a tftp server. The corresponding file storage folder
will be mapped to the top level resource folder of the container.

## Configuration Options:

* tftp_folder: Top level resource folder of the container.
* tftp_port: TFTP port that will be exposed on your local host.
